// Copyright (c) 2012-2013, IGN France.
// Copyright (c) 2012-2022, Oslandia.
// SPDX-License-Identifier: LGPL-2.0-or-later

#include <SFCGAL/detail/graph/Vertex.h>

namespace SFCGAL::graph {

///
///
///
Vertex::Vertex(const Coordinate &coordinate_) : coordinate(coordinate_) {}

} // namespace SFCGAL::graph
